@@ -273,7 +273,9 @@ void Subscriptions::update() {
         FeedRequest *request = feedRequest(source.value("pluginId").toString());
         
         if (request) {
-            request->getFeed(source.value("settings").toMap());
+            QVariantMap settings = source.value("settings").toMap();
+            settings["lastUpdated"] = subscription()->lastUpdated();
+            request->getFeed(settings);
         }
         else {
             next();
@@ -305,20 +307,6 @@ void Subscriptions::update() {
     }
 }
 
-static QString replaceImageUrls(const QString &body, const QString &cachePath) {
-    QString result(body);
-    const QRegExp src(" src=('|\")([^'\"]+)");
-    int pos = 0;
-
-    while ((pos = src.indexIn(body, pos)) != -1) {
-        const QString url = src.cap(2);
-        result.replace(url, cachePath + url.toUtf8().toBase64());
-        pos += src.matchedLength();
-    }
-
-    return result;
-}
-
 void Subscriptions::parseXml(const QByteArray &xml) {
     FeedParser parser(xml);
     
@@ -329,7 +317,7 @@ void Subscriptions::parseXml(const QByteArray &xml) {
         return;
     }
     
-    const QString channelTitle = parser.title();
+    const QString channelTitle = Utils::unescapeHtml(parser.title());
     const QString channelDescription = parser.description();
     const QString channelUrl = parser.url();
     const QString channelIconUrl = parser.iconUrl();
@@ -375,12 +363,11 @@ void Subscriptions::parseXml(const QByteArray &xml) {
     
     QString id = Utils::createId();
     QDateTime date = parser.date();
-    QVariantList enc = parser.enclosures();    
+    QVariantList enc = parser.enclosures();
     QVariantList ids = QVariantList() << id;
     QVariantList authors = QVariantList() << parser.author();
-    QVariantList bodies = QVariantList() << replaceImageUrls(parser.description(), QString("%1%2%3/%4/")
-                                                             .arg(CACHE_AUTHORITY).arg(CACHE_PATH).arg(subscriptionId)
-                                                             .arg(id));
+    QVariantList bodies = QVariantList() << Utils::replaceSrcPaths(parser.description(), QString("%1%2%3/%4/")
+            .arg(CACHE_AUTHORITY).arg(CACHE_PATH).arg(subscriptionId).arg(id));
     QVariantList categories = QVariantList() << parser.categories().join(", ");
     QVariantList dates = QVariantList() << date.toTime_t();
     QVariantList enclosures = QVariantList() << QtJson::Json::serialize(enc);
@@ -388,7 +375,7 @@ void Subscriptions::parseXml(const QByteArray &xml) {
     QVariantList reads = QVariantList() << 0;
     QVariantList lastReads = QVariantList() << 0;
     QVariantList subscriptionIds = QVariantList() << subscriptionId;
-    QVariantList titles = QVariantList() << parser.title();
+    QVariantList titles = QVariantList() << Utils::unescapeHtml(parser.title());
     QVariantList urls = QVariantList() << parser.url();
     
     if (subscription()->downloadEnclosures()) {
@@ -402,8 +389,8 @@ void Subscriptions::parseXml(const QByteArray &xml) {
         enc = parser.enclosures();
         ids << id;
         authors << parser.author();
-        bodies << replaceImageUrls(parser.description(), QString("%1%2%3/%4/").arg(CACHE_AUTHORITY).arg(CACHE_PATH)
-                                   .arg(subscriptionId).arg(id));
+        bodies << Utils::replaceSrcPaths(parser.description(), QString("%1%2%3/%4/").arg(CACHE_AUTHORITY)
+                .arg(CACHE_PATH).arg(subscriptionId).arg(id));
         categories << parser.categories().join(", ");
         dates << parser.date().toTime_t();
         enclosures << QtJson::Json::serialize(enc);
@@ -411,7 +398,7 @@ void Subscriptions::parseXml(const QByteArray &xml) {
         reads << 0;
         lastReads << 0;
         subscriptionIds << subscriptionId;
-        titles << parser.title();
+        titles << Utils::unescapeHtml(parser.title());
         urls << parser.url();
 
         if (subscription()->downloadEnclosures()) {
@@ -421,8 +408,8 @@ void Subscriptions::parseXml(const QByteArray &xml) {
         }
     }
     
-    Logger::log(QString("Subscriptions::parseXml(). %1 new articles found since %2 for subscription %3").arg(ids.size())
-                .arg(lastUpdated.toString()).arg(subscriptionId), Logger::LowVerbosity);
+    Logger::log(QString("Subscriptions::parseXml(). %1 new articles found since %2 for subscription %3")
+            .arg(ids.size()).arg(lastUpdated.toString()).arg(subscriptionId), Logger::LowVerbosity);
     
     DBConnection::connection(this, SLOT(onConnectionFinished(DBConnection*)))->addArticles(QList<QVariantList>()
                              << ids << authors << bodies << categories << dates << enclosures << favourites << reads
