@@ -397,6 +397,20 @@ void Settings::setReadArticleExpiry(int expiry) {
     }
 }
 
+int Settings::screenOrientation() {
+    return value("UI/screenOrientation", Qt::WA_Maemo5LandscapeOrientation).toInt();
+}
+
+void Settings::setScreenOrientation(int orientation) {
+    if (orientation != screenOrientation()) {
+        setValue("UI/screenOrientation", orientation);
+        
+        if (self) {
+            emit self->screenOrientationChanged(orientation);
+        }
+    }
+}
+
 bool Settings::startTransfersAutomatically() {
     return value("Transfers/startTransfersAutomatically", true).toBool();
 }
@@ -817,6 +831,20 @@ void Settings::setUpdateSubscriptionShortcut(const QString &key) {
     }
 }
 
+bool Settings::volumeKeysEnabled() {
+    return value("Shortcuts/volumeKeysEnabled", false).toBool();
+}
+
+void Settings::setVolumeKeysEnabled(bool enabled) {
+    if (enabled != volumeKeysEnabled()) {
+        setValue("Shortcuts/volumeKeysEnabled", enabled);
+
+        if (self) {
+            emit self->volumeKeysEnabledChanged(enabled);
+        }
+    }
+}
+
 QVariant Settings::value(const QString &key, const QVariant &defaultValue) {
     return QSettings(APP_CONFIG_PATH + "settings", QSettings::IniFormat).value(key, defaultValue);
 }
